Workflow
========

``Workflow`` is a simple python library to handle finite state machines, a.k.a objects that always have a
state amongst a finite list of possible states and transitions between those states.

Read the docs: http://edgyworkflow.rtfd.org/
